# TOPSIS Package in Python

Submitted by: Ishtdeep Singh Sodhi

Roll no: 102003315

---

## TOPSIS

The Technique for Order of Preference by Similarity to Ideal Solution (TOPSIS) is a multi-criteria decision analysis method, which was originally developed by Ching-Lai Hwang and Yoon in 1981,with further developments by Yoon in 1987,and Hwang, Lai and Liu in 1993.TOPSIS is based on the concept that the chosen alternative should have the shortest geometric distance from the positive ideal solution (PIS) and the longest geometric distance from the negative ideal solution (NIS).

---

## How to use

The package Topsis-Ishtdeep-102003315 can be run though the command line as follows:

```
>> pip install Topsis-Ishtdeep-102003315
```

```
>>topsis data1.csv "1,1,1,1,1" "+,+,+,+,+" result.csv
```

<br>
The output file contains columns of input file along with two additional columns having Topsis_score and Rank.

---
